@@ -53,15 +53,18 @@
 # @keyword "univar"
 # @keyword "robust"
 #*/############################################################################
-weightedMad <- function(x, w, na.rm=FALSE, constant=1.4826, center=NULL, ...) {
+weightedMad <- function(x, w=NULL, na.rm=FALSE, constant=1.4826, center=NULL, ...) {
+  # No weights? Fall back to non-weighted method.
+  if (is.null(w)) {
+    if (is.null(center)) center <- median(x, na.rm=na.rm)
+    return(mad(x, center=center, constant=constant, na.rm=na.rm, ...))
+  }
+
   # Argument 'x':
   n <- length(x);
 
   # Argument 'w':
-  if (missing(w)) {
-    # By default use weights that are one.
-    w <- rep(1, times=n);
-  } else if (length(w) != n) {
+  if (length(w) != n) {
     stop("The number of elements in arguments 'w' and 'x' does not match: ", length(w), " != ", n);
   }
 
