@@ -57,11 +57,19 @@
 # @keyword "univar"
 # @keyword "robust"
 #*/############################################################################
-weightedMean <- function(x, w, na.rm=FALSE, refine=FALSE, ...) {
+weightedMean <- function(x, w=NULL, na.rm=FALSE, refine=FALSE, ...) {
   # Argument 'refine':
   refine <- as.logical(refine)
 
-  w <- as.numeric(w)
+  # Argument 'w':
+  if (is.null(w)) {
+    ## We won't fall back to stats::mean(), because it's has some overhead
+    ## and it doesn't support refine=FALSE.
+    w <- rep(1, times=length(x))
+  } else {
+    w <- as.numeric(w)
+  }
+
   .Call("weightedMean", x, w, na.rm, refine, PACKAGE="matrixStats")
 } # weightedMean()
 
