@@ -1,13 +1,27 @@
 ############################################################################/**
 # @RdocFunction weightedVar
 # @alias weightedSd
+# @alias colWeightedVars
+# @alias rowWeightedVars
+# @alias colWeightedSds
+# @alias rowWeightedSds
 #
-# @title "Weighted variance"
+# @title "Weighted variance and weighted standard deviation"
+#
+# \usage{
+#  @usage weightedVar
+#  @usage colWeightedVars
+#  @usage rowWeightedVars
+#
+#  @usage weightedSd
+#  @usage colWeightedSds
+#  @usage rowWeightedSds
+# }
 #
-# @synopsis
 #
 # \description{
-#   Computes a weighted variance of a numeric vector.
+#   Computes a weighted variance / standard deviation of a numeric
+#   vector or across rows or columns of a matrix.
 # }
 #
 # \arguments{
@@ -34,6 +48,15 @@
 #   \code{na.rm} is @TRUE, otherwise not.
 # }
 #
+# \section{Weighted variance}{
+#   The weights used by the weighted variance (and standard deviation)
+#   estimator should be consider so called \emph{frequency weights} such
+#   that \code{weightedVar(c(2,4,5), w=c(2,1,3)) == var(c(2, 2, 4, 5, 5, 5))}.
+#   Note that this means that the estimate is \emph{not} invariant
+#   to a scale factor on the weights, e.g. passing normalized weights
+#   will not give the same estimate as non-normalized weights.
+# }
+#
 # \seealso{
 #   For the non-weighted variance, see @see "stats::var".
 # }
@@ -43,20 +66,26 @@
 # @keyword "univar"
 # @keyword "robust"
 #*/############################################################################
-weightedVar <- function(x, w, na.rm=FALSE, center=NULL, ...) {
+weightedVar <- function(x, w=NULL, na.rm=FALSE, center=NULL, ...) {
   # Argument 'x':
   n <- length(x);
 
   # Argument 'w':
-  if (missing(w)) {
-    # By default use weights that are one.
-    w <- rep(1, times=n);
+  if (is.null(w)) {
+    w <- rep(1, times=n)
   } else if (length(w) != n) {
-    throw("The number of elements in arguments 'w' and 'x' does not match: ", length(w), " != ", n);
+    stop("The number of elements in arguments 'w' and 'x' does not match: ", length(w), " != ", n);
   }
 
   # Argument 'na.rm':
 
+  # Argument 'method':
+  method <- list(...)$method
+
+  ## Backward compatible but incorrect estimate?
+  ## See https://github.com/HenrikBengtsson/matrixStats/issues/72
+  use_0.14.2 <- (identical(method, "0.14.2"))
+
 
   naValue <- NA;
   storage.mode(naValue) <- storage.mode(x);
@@ -97,18 +126,13 @@ weightedVar <- function(x, w, na.rm=FALSE, center=NULL, ...) {
   tmp <- NULL; # Not needed anymore
 
 
-  # Are there any values left to calculate the weighted median of?
-  # This is consistent with how stats::mad() works.
-  if (n == 0L) {
-    return(naValue);
-  } else if (n == 1L) {
-    zeroValue <- 0;
-    storage.mode(zeroValue) <- storage.mode(x);
-    return(zeroValue);
-  }
+  # Are there any values left to calculate the weighted variance of?
+  # This is consistent with how stats::var() works.
+  if (n <= 1L) return(naValue)
 
   # Standardize weights to sum to one
-  w <- w / sum(w);
+  wsum <- sum(w)
+  w <- w / wsum
 
   # Estimate the mean?
   if (is.null(center)) {
@@ -118,7 +142,12 @@ weightedVar <- function(x, w, na.rm=FALSE, center=NULL, ...) {
   # Estimate the variance
   x <- x - center; # Residuals
   x <- x^2;        # Squared residuals
-  sigma2 <- sum(w*x) * (n / (n-1L))
+
+  ## Correction factor
+  lambda <- wsum / (wsum - 1)
+  if (use_0.14.2) lambda <- n / (n-1L)
+
+  sigma2 <- lambda * sum(w*x)
 
   x <- w <- NULL; # Not needed anymore
 
@@ -130,6 +159,24 @@ weightedSd <- function(...) {
 } # weightedSd()
 
 
+rowWeightedVars <- function(x, w=NULL, na.rm=FALSE, ...) {
+  apply(x, MARGIN=1L, FUN=weightedVar, w=w, na.rm=na.rm, ...)
+} # rowWeightedVars()
+
+colWeightedVars <- function(x, w=NULL, na.rm=FALSE, ...) {
+  apply(x, MARGIN=2L, FUN=weightedVar, w=w, na.rm=na.rm, ...)
+} # colWeightedVars()
+
+
+rowWeightedSds <- function(x, w=NULL, na.rm=FALSE, ...) {
+  sqrt(rowWeightedVars(x=x, w=w, na.rm=na.rm, ...))
+} # rowWeightedSds()
+
+colWeightedSds <- function(x, w=NULL, na.rm=FALSE, ...) {
+  sqrt(colWeightedVars(x=x, w=w, na.rm=na.rm, ...))
+} # colWeightedSds()
+
+
 ############################################################################
 # HISTORY:
 # 2014-11-10
