@@ -28,6 +28,7 @@ double METHOD_NAME(X_C_TYPE *x, R_xlen_t nx, int narm, int hasna) {
   LDOUBLE y = 0.0, t;
   R_xlen_t ii;
   int isneg = 0;
+  int hasZero = 0;
 
   /* Calculate sum(log(abs(x))) */
   for (ii = 0 ; ii < nx; ii++) {
@@ -46,8 +47,9 @@ double METHOD_NAME(X_C_TYPE *x, R_xlen_t nx, int narm, int hasna) {
       isneg = !isneg;
       t = -t;
     } else if (t == 0) {
-      y = R_NegInf;
-      break;
+      hasZero = 1;
+      /* Early stopping? */
+      if (narm) break;
     }
 #elif X_TYPE == 'r'
     if (t < 0) {
@@ -59,6 +61,11 @@ double METHOD_NAME(X_C_TYPE *x, R_xlen_t nx, int narm, int hasna) {
     y += t;
     /*
       Rprintf("#%d: x=%g, is.nan(x)=%d, abs(x)=%g, is.nan(abs(x))=%d, log(abs(x))=%g, is.nan(log(abs(x)))=%d, sum=%g, is.nan(sum)=%d\n", ii, x[ii], R_IsNaN(x[ii]), X_ABS(x[ii]), R_IsNaN(abs(x[ii])), t, R_IsNaN(y), y, R_IsNaN(y));  */
+
+#if X_TYPE == 'r'
+    /* Early stopping? Special for long LDOUBLE vectors */
+    if (ii % 1048576 == 0 && ISNAN(y)) break;
+#endif
   }
 
   if (ISNAN(y)) {
@@ -67,6 +74,9 @@ double METHOD_NAME(X_C_TYPE *x, R_xlen_t nx, int narm, int hasna) {
        calculating fabs(NA), which returns NaN. For consistency with
        integers, we return NA in all cases. */
     y = NA_REAL;
+  } else if (hasZero) {
+    /* no NA in 'x' and 'x' contains zero */
+    y = 0;
   } else {
     y = exp(y);
   
